#ifndef _ELM_MULTIBUTTONENTRY_PART_EO_H_
#define _ELM_MULTIBUTTONENTRY_PART_EO_H_

#ifndef _ELM_MULTIBUTTONENTRY_PART_EO_CLASS_TYPE
#define _ELM_MULTIBUTTONENTRY_PART_EO_CLASS_TYPE

typedef Eo Elm_Multibuttonentry_Part;

#endif

#ifndef _ELM_MULTIBUTTONENTRY_PART_EO_TYPES
#define _ELM_MULTIBUTTONENTRY_PART_EO_TYPES


#endif
#ifdef EFL_BETA_API_SUPPORT
/** Elementary multibuttonentry internal part class
 *
 * @ingroup Elm_Multibuttonentry_Part
 */
#define ELM_MULTIBUTTONENTRY_PART_CLASS elm_multibuttonentry_part_class_get()

EWAPI const Efl_Class *elm_multibuttonentry_part_class_get(void);
#endif /* EFL_BETA_API_SUPPORT */

#endif
